@@ -4,7 +4,7 @@
 
     transcode_handler.cc - this file is part of Gerbera.
 
-    Copyright (C) 2021-2024 Gerbera Contributors
+    Copyright (C) 2021-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -22,15 +22,17 @@
 */
 
 /// \file transcode_handler.cc
-#define LOG_FAC log_facility_t::transcoding
+#define GRB_LOG_FAC GrbLogFacility::transcoding
 
 #include "transcode_handler.h" // API
 
-#include "content/content_manager.h"
+#include "content/content.h"
 #include "context.h"
 
-TranscodeHandler::TranscodeHandler(const std::shared_ptr<ContentManager>& content)
+TranscodeHandler::TranscodeHandler(const std::shared_ptr<Content>& content)
     : config(content->getContext()->getConfig())
     , content(content)
 {
 }
+
+TranscodeHandler::~TranscodeHandler() = default;
